@@ -27,7 +27,7 @@ class Sources extends BaseController {
 
         // load sources
         $sourcesDao = new \daos\Sources();
-        echo '<div class="source-add">' . \F3::get('lang_source_add') . '</div>' .
+        echo '<button class="source-add">' . \F3::get('lang_source_add') . '</button>' .
              '<a class="source-export" href="opmlexport">' . \F3::get('lang_source_export') . '</a>' .
              '<a class="source-opml" href="opml">' . \F3::get('lang_source_opml');
         $sourcesHtml = '</a>';
@@ -77,8 +77,10 @@ class Sources extends BaseController {
         if($this->view->spout===false)
             $this->view->error('invalid spout type given');
         
-        if($this->view->spout->params!==false)
+        if($this->view->spout->params!==false) {
+            $this->view->idAttr = 'new-' . rand();
             echo $this->view->render('templates/source_params.phtml');
+        }
     }
     
     
