@@ -56,7 +56,7 @@ class Database {
                         source INT NOT NULL ,
                         uid VARCHAR(255) NOT NULL,
                         link TEXT NOT NULL,
-                        updatetime DATETIME NOT NULL,
+                        updatetime DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
                         author VARCHAR(255),
                         INDEX (source)
                     ) ENGINE = InnoDB DEFAULT CHARSET=utf8;
@@ -181,6 +181,14 @@ class Database {
                         INSERT INTO '.\F3::get('db_prefix').'version (version) VALUES (8);
                     ');
                 }
+				if(strnatcmp($version, "9") < 0) {
+					\F3::get('db')->exec('
+                        ALTER TABLE '.\F3::get('db_prefix').'items ADD shared BOOL;
+                    ');
+					\F3::get('db')->exec('
+                        INSERT INTO version (version) VALUES (9);
+                    ');
+				}
             }
             
             // just initialize once
