@@ -1,7 +1,7 @@
 <?php
 
 /*
-	Copyright (c) 2009-2013 F3::Factory/Bong Cosca, All rights reserved.
+	Copyright (c) 2009-2014 F3::Factory/Bong Cosca, All rights reserved.
 
 	This file is part of the Fat-Free Framework (http://fatfree.sf.net).
 
@@ -18,6 +18,10 @@ namespace DB\Mongo;
 //! MongoDB-managed session handler
 class Session extends Mapper {
 
+	protected
+		//! Session ID
+		$sid;
+
 	/**
 	*	Open session
 	*	@return TRUE
@@ -42,7 +46,8 @@ class Session extends Mapper {
 	*	@param $id string
 	**/
 	function read($id) {
-		$this->load(array('session_id'=>$id));
+		if ($id!=$this->sid)
+			$this->load(array('session_id'=>$this->sid=$id));
 		return $this->dry()?FALSE:$this->get('data');
 	}
 
@@ -56,7 +61,8 @@ class Session extends Mapper {
 		$fw=\Base::instance();
 		$sent=headers_sent();
 		$headers=$fw->get('HEADERS');
-		$this->load(array('session_id'=>$id));
+		if ($id!=$this->sid)
+			$this->load(array('session_id'=>$this->sid=$id));
 		$csrf=$fw->hash($fw->get('ROOT').$fw->get('BASE')).'.'.
 			$fw->hash(mt_rand());
 		$this->set('session_id',$id);
@@ -68,7 +74,7 @@ class Session extends Mapper {
 		$this->set('stamp',time());
 		$this->save();
 		if (!$sent) {
-			if ($_COOKIE['_'])
+			if (isset($_COOKIE['_']))
 				setcookie('_','',strtotime('-1 year'));
 			call_user_func_array('setcookie',
 				array('_',$csrf)+$fw->get('JAR'));
@@ -100,42 +106,34 @@ class Session extends Mapper {
 	}
 
 	/**
-	*	Return anti-CSRF tokan associated with specified session ID
+	*	Return anti-CSRF token
 	*	@return string|FALSE
-	*	@param $id string
 	**/
-	function csrf($id=NULL) {
-		$this->load(array('session_id'=>$id?:session_id()));
+	function csrf() {
 		return $this->dry()?FALSE:$this->get('csrf');
 	}
 
 	/**
-	*	Return IP address associated with specified session ID
+	*	Return IP address
 	*	@return string|FALSE
-	*	@param $id string
 	**/
-	function ip($id=NULL) {
-		$this->load(array('session_id'=>$id?:session_id()));
+	function ip() {
 		return $this->dry()?FALSE:$this->get('ip');
 	}
 
 	/**
-	*	Return Unix timestamp associated with specified session ID
+	*	Return Unix timestamp
 	*	@return string|FALSE
-	*	@param $id string
 	**/
-	function stamp($id=NULL) {
-		$this->load(array('session_id'=>$id?:session_id()));
+	function stamp() {
 		return $this->dry()?FALSE:$this->get('stamp');
 	}
 
 	/**
-	*	Return HTTP user agent associated with specified session ID
+	*	Return HTTP user agent
 	*	@return string|FALSE
-	*	@param $id string
 	**/
-	function agent($id=NULL) {
-		$this->load(array('session_id'=>$id?:session_id()));
+	function agent() {
 		return $this->dry()?FALSE:$this->get('agent');
 	}
 
@@ -158,26 +156,18 @@ class Session extends Mapper {
 		@session_start();
 		$fw=\Base::instance();
 		$headers=$fw->get('HEADERS');
-		if (($csrf=$this->csrf()) &&
-			((!isset($_COOKIE['_']) || $_COOKIE['_']!=$csrf) ||
-			($ip=$this->ip()) && $ip!=$fw->get('IP') ||
-			($agent=$this->agent()) && !isset($headers['User-Agent']) ||
+		if (($ip=$this->ip()) && $ip!=$fw->get('IP') ||
+			($agent=$this->agent()) &&
+			(!isset($headers['User-Agent']) ||
 				$agent!=$headers['User-Agent'])) {
-			$jar=$fw->get('JAR');
-			$jar['expire']=strtotime('-1 year');
-			call_user_func_array('setcookie',
-				array_merge(array('_',''),$jar));
-			unset($_COOKIE['_']);
 			session_destroy();
-			\Base::instance()->error(403);
+			$fw->error(403);
 		}
 		$csrf=$fw->hash($fw->get('ROOT').$fw->get('BASE')).'.'.
 			$fw->hash(mt_rand());
-		if ($this->load(array('session_id'=>session_id()))) {
+		if ($this->load(array('session_id'=>$this->sid=session_id()))) {
 			$this->set('csrf',$csrf);
 			$this->save();
-			call_user_func_array('setcookie',
-				array('_',$csrf)+$fw->get('JAR'));
 		}
 	}
 
