@@ -84,6 +84,9 @@ selfoss.events.entries = function(e) {
                 parent.find('.entry-toolbar').hide();
                 content.hide();
             } else {
+                if($('#config').data('auto_collapse')=="1"){
+                    $('.entry-content, .entry-toolbar').hide();
+                }
                 content.show();
                 selfoss.events.entriesToolbar(parent);
                 parent.find('.entry-toolbar').show();
@@ -98,12 +101,19 @@ selfoss.events.entries = function(e) {
 
                 // scroll to article header
                 parent.get(0).scrollIntoView();
+
+                // update the floating unread count after every image load
+                // since they might resize the entry container
+                content.find('img').load(selfoss.events.updateUnreadBelowTheFold);
             }
             
             // load images not on mobile devices
             if(selfoss.isMobile()==false || $('#config').data('load_images_on_mobile')=="1") {
                 content.lazyLoadImages();
             }
+
+            // update the floating unread count
+            selfoss.events.updateUnreadBelowTheFold();
         } 
     });
 
@@ -122,10 +132,17 @@ selfoss.events.entries = function(e) {
            && $('.stream-more').position().top < $(window).height() + $(window).scrollTop() 
            && $('.stream-more').hasClass('loading')==false)
             $('.stream-more').click();
+
+        if ($('#floating-unread').is(':visible')) {
+            // update the floating unread count
+            selfoss.events.updateUnreadBelowTheFold();
+        }
     });
     
     $('.mark-these-read').unbind('click').click(selfoss.markVisibleRead);
 
+    $('.stream-error').unbind('click').click(selfoss.reloadList);
+
     // more
     $('.stream-more').unbind('click').click(function () {
         var streamMore = $(this);
